=======
 keres 
=======


Introduction
------------

Keres is a Bayes filter for amyloid fibrillogenesis fluorimetry data
and a suite to test the filter.

The test suite requires the `copasi simulator`_.


Home Page & Repository
----------------------

- Home Page: http://pypi.python.org/pypi/keres
- Repository: https://github.com/jcstroud/keres.git


Example
-------

An example of use is in the "examples" directory.
There are two ways to try the example.

    1. Change to the directory and run the command::

          ./test-bayes settings.cfg

    2. Install the package, ensuring that the bin directory
       of your pythong install is in your path::

          bayestest settings.cfg


.. _`copasi simulator`: http://www.copasi.org/tiki-view_articles.php
